var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import _ from 'lodash';
const watchOptions = {
    enableHighAccuracy: true,
    timeout: 5000,
};
class LocationServiceImplementation {
    constructor() {
        /**
         * Calculates area including delta for a collection of coordiantes
         * @param {Array<Coordinates>} - array of coordinates
         */
        this.getMapPointForCoordiantes = (coordinates) => {
            let minX;
            let maxX;
            let minY;
            let maxY;
            // init first point
            ((point) => {
                minX = point.latitude;
                maxX = point.latitude;
                minY = point.longitude;
                maxY = point.longitude;
            })(coordinates[0]);
            _.map(coordinates, (point) => 
            // calculate rect
            ({
                minX: Math.min(minX, point.latitude),
                maxX: Math.max(maxX, point.latitude),
                minY: Math.min(minY, point.longitude),
                maxY: Math.max(maxY, point.longitude),
            }));
            const midX = (minX + maxX) / 2;
            const midY = (minY + maxY) / 2;
            const deltaX = maxX - minX;
            const deltaY = maxY - minY;
            /**
             * @type {MapPoint}
             */
            const location = {
                latitude: midX,
                longitude: midY,
                latitudeDelta: deltaX,
                longitudeDelta: deltaY,
            };
            return location;
        };
        this.getCurrentLocation = () => {
            return new Promise((resolve) => {
                //using react native's location system
                navigator.geolocation.getCurrentPosition((position) => {
                    console.log('** LocationService: user location **');
                    console.log(position);
                    const result = {
                        latitude: position.coords.latitude,
                        longitude: position.coords.longitude,
                    };
                    console.log(result);
                    resolve(result);
                }, (error) => {
                    console.log(error);
                    throw Error(error.message);
                });
            });
        };
    }
    /**
     * Watch for location changes
     * @param locationChanged Callback that occurs when location changes
     */
    watchLocation(locationChanged) {
        // @ts-ignore - bad mappings
        navigator.geolocation.stopObserving();
        // Get the user's current location and watch
        navigator.geolocation.watchPosition((location) => {
            if (_.isNil(location)) {
                return new Error('Failed to get location');
            }
            const result = {
                latitude: location.coords.latitude,
                longitude: location.coords.longitude,
            };
            // Send result to callback
            if (!_.isNil(locationChanged)) {
                locationChanged(result);
            }
            // Returns number?
            return 0;
        }, (error) => __awaiter(this, void 0, void 0, function* () {
            return new Error(error.message);
        }), watchOptions);
    }
}
const LocationService = new LocationServiceImplementation();
export default LocationService;
//# sourceMappingURL=LocationService.js.map