import * as types from '../../types';
import MapView from 'react-native-maps';
export interface IFitToCoordOptions {
    edgePadding: types.IEdgePadding;
    animated: boolean;
}
/**
 * Animates map to the specified coordinates
 *
 * @param {number} lat
 * @param {number} long
 * @memberof MapService
 * @public
 */
export declare const goToCoordinate: (map: MapView, coordinate: types.ILatLng) => void;
/**
 * Animate to the specified viewing angle
 *
 * @see https://github.com/react-community/react-native-maps/blob/master/docs/mapview.md#methods
 *
 * @param {number} angle
 * @param {number} duration animation speed
 * @returns
 * @memberof MapService
 */
export declare const goToAngle: (map: MapView, angle: number, duration?: number | undefined) => void;
/**
 * Animate to the specified bearing
 *
 * @see https://github.com/react-community/react-native-maps/blob/master/docs/mapview.md#methods
 *
 * @param {number} bearing
 * @param {number} duration animation speed
 * @returns
 * @memberof MapService
 */
export declare const goToBearing: (map: MapView, bearing: number, duration?: number | undefined) => void;
/**
 * Fit the map to supplied coordinates
 *
 * @param {Array<types.ILatLng>} coordinates
 * @param {{ edgePadding: types.IEdgePadding, animated: Boolean }} options
 * @returns
 * @memberof MapService
 */
export declare const fitToCoordinates: (map: MapView, coordinates: types.ILatLng[], options?: IFitToCoordOptions | undefined) => void;
export declare const zoomToLevel: (map: MapView, location: types.ILatLng, zoomLevel: number) => void;
/**
 * Animate to location in map state if available
 *
 * @memberof MapService
 * @public
 *
 * @param {Object} userLocation
 */
export declare const goToUserLocation: (map: MapView, userLocation: types.ILatLng) => void;
//# sourceMappingURL=MapService.d.ts.map