/**
 * Map action types
 * @constant
 * @public
 * @typedef MapConstants
 * @type {Object}
 */
export declare enum MapConstants {
    MAP_LOCATION_BUSY = "Letar upp dig",
    MAP_LOCATION_SUCCESS = "MAP = GET LOCATION SUCCESS",
    MAP_LOCATION_FAILED = "MAP = GET LOCATION FAILED"
}
/**
 * Describes coordiantes for a location on the map
 * @typedef ILocation
 * @type {Object}
 * @public
 * @export
 * @property {number?} latitude
 * @property {number?} longitude
 * @public
 */
export interface ILatLng {
    latitude: number;
    longitude: number;
}
/**
 * Describes an area on the map
 *
 * @export
 * @interface ILocation
 * @extends {ILatLng}
 * @property {number?} latitudeDelta
 * @property {number?} longitudeDelta
 */
export interface IRegion {
    latitude: number;
    longitude: number;
    latitudeDelta: number;
    longitudeDelta: number;
}
export interface MapViewDirectionsProps {
    origin?: Array<any>;
    waypoints?: Array<any>;
    destination?: Array<any>;
    apikey: string;
    onStart?(): void;
    onReady?(): void;
    onError?(): void;
    mode?: 'DRIVING' | 'BICYCLING' | 'TRANSIT' | 'WALKING';
    language?: string;
    resetOnChange?: boolean;
    optimizeWaypoints?: boolean;
    directionsServiceBaseUrl?: string;
    region?: string;
}
export interface ILocation extends ILatLng {
    altitude: Number;
    timestamp: Number;
    accuracy: Number;
    altitudeAccuracy: Number;
    speed: Number;
}
/**
 * Describes padding on the map
 *
 * @export
 * @interface IEdgePadding
 */
export interface IEdgePadding {
    top: Number;
    right: Number;
    bottom: Number;
    left: Number;
}
/**
 * Describes a pin on the map
 *
 * @export
 * @interface IMapPin
 */
export interface IMapPin {
    isUser: boolean;
    location: string;
    title?: string;
    description?: string;
}
/**
 * Reduced properties passed down from LoginReducer
 * @typedef IMapState
 * @export
 * @public
 * @property {ILocation} location
 * @property {boolean} isUserSearch
 */
export interface IMapState {
    location: IRegion;
    /**
     * determines if the location changed from user search. Default is false
     *
     * @type {boolean}
     * @memberof IMapState
     */
    isUserSearch: boolean;
    __typename: MapConstants;
}
/**
 * Creates a new {IMapState}
 * @param location user location
 * @param isUserSearch determines if the location changed from user search. Default is false
 * @param type action type
 */
export declare const MapState: (location?: IRegion, isUserSearch?: boolean, __typename?: MapConstants) => IMapState;
//# sourceMappingURL=types.d.ts.map